@@ -185,7 +185,8 @@ void Account::disconnected( DisconnectReason reason )
 	}
 	else if ( Kopete::BehaviorSettings::self()->reconnectOnDisconnect() == true && reason > Manual )
 	{
-		if (reason == ConnectionReset) {
+		bool networkAvailable = ( Solid::Networking::status() == Solid::Networking::Unknown || Solid::Networking::status() == Solid::Networking::Connected );
+		if ( reason == ConnectionReset && ! networkAvailable ) {
 			d->reconnectOnNetworkIsOnline = true;
 			d->reconnectTimer.stop();
 		} else {
@@ -472,7 +473,7 @@ void Account::fillActionMenu( KActionMenu *actionMenu )
        	if (identity()->hasProperty( Kopete::Global::Properties::self()->nickName().key() ))
 		nick = identity()->property( Kopete::Global::Properties::self()->nickName() ).value().toString();
 	else
-		nick = myself()->nickName();
+		nick = myself()->displayName();
 
 	// Always add title at the beginning of actionMenu
 	QAction *before = actionMenu->menu()->actions().value( 0, 0 );
